@@ -178,6 +178,12 @@ html_url_new (const gchar *s)
 					       ((reference_ptr - 1)
 						- path_start));
 	} else {
+#ifdef G_OS_WIN32
+		if (path_start[0] == '/' &&
+		    g_ascii_isalpha (path_start[1]) &&
+		    path_start[2] == ':')
+			path_start++;
+#endif
 		new->path = strdup_nonempty_or_null (path_start);
 	}
 
@@ -299,13 +305,13 @@ html_url_set_port (HTMLURL *url, gushort port)
 }
 
 
-#define GET_STR_FUNC(member)			\
-const gchar *					\
-html_url_get_##member (const HTMLURL *url)	\
-{						\
-	g_return_val_if_fail (url != NULL, 0);	\
-						\
-	return url->member;			\
+#define GET_STR_FUNC(member)				\
+const gchar *						\
+html_url_get_##member (const HTMLURL *url)		\
+{							\
+	g_return_val_if_fail (url != NULL, NULL);	\
+							\
+	return url->member;				\
 }
 
 GET_STR_FUNC (protocol)
